@@ -11,6 +11,8 @@ import os
 
 import numpy as np
 import tensorstore as ts
+import zarr
+from tifffile import imread
 
 
 # Miscellaneous routines
@@ -34,7 +36,7 @@ def get_value(volume, graph, i):
 
     """
     idx = get_idx(graph, i)
-    return volume[idx] if idx in volume.keys() else 0
+    return volume[idx]
 
 
 def mkdir(path_to_dir):
@@ -107,13 +109,35 @@ def remove_edge(set_of_edges, edge):
     return set_of_edges
 
 
-def upload_tensorstore_mask(data_dir):
+def clip(arr, clip):
+    """
+    Clips an array.
+
+    Parameters
+    ----------
+    arr : numpy.array
+        Array to be clipped.
+    clip : int
+        Number of rows/columns to be removed from each dimensions.
+
+    Returns
+    -------
+    clipped_arr : numpy.array
+        Clipped array.
+
+    """
+    clipped_arr = arr[clip:-clip, clip:-clip, clip:-clip]
+    return clipped_arr
+
+
+# Upload routines
+def upload_tensorstore(path_to_data):
     """
     Uploads segmentation mask stored as a directory of shard files.
 
     Parameters
     ----------
-    data_dir : str
+    path_to_data : str
         Path to directory containing shard files.
 
     Returns
@@ -127,7 +151,7 @@ def upload_tensorstore_mask(data_dir):
             "driver": "neuroglancer_precomputed",
             "kvstore": {
                 "driver": "file",
-                "path": data_dir,
+                "path": path_to_data,
             },
         }
     ).result()
@@ -142,6 +166,40 @@ def upload_tensorstore_mask(data_dir):
     return sparse_volume
 
 
+def upload_n5(path_to_data):
+    """
+    Uploads n5 file.
+
+    Parameters
+    ----------
+    path_to_data : str
+        Path to n5.
+
+    Returns
+    -------
+    np.array
+        Image volume.
+    """
+    return zarr.open(zarr.N5FSStore(path_to_data), "r").volume
+
+
+def upload_tif(path_to_data):
+    """
+    Uploads tif file.
+
+    Parameters
+    ----------
+    path_to_data : str
+        Path to tif file.
+
+    Returns
+    -------
+    np.array
+        Image volume.
+    """
+    return imread(path_to_data)
+
+
 # Networkx helper routines
 def get_nbs(graph, i):
     """
